;;; ~/.doom.d/+ui.el -*- lexical-binding: t; -*-
;; Appearance settings
;; Set Font and theme
(setq doom-font (font-spec :family "Iosevka Medium" :size 26)
      doom-theme 'doom-one)
;; Display Magit status in fullscreen
(after! magit
  (setq magit-display-buffer-function #'magit-display-buffer-fullframe-status-v1))
;; Match pdf-tools colors to the theme and fit to page by default
(after! pdf-tools
  (setq pdf-view-midnight-colors '("#BBC2CF" . "#282C34"))
  (setq-default pdf-view-display-size 'fit-width)
  (add-hook 'pdf-tools-enabled-hook 'pdf-view-midnight-minor-mode))
;; Customize modeline
(setq doom-modeline-major-mode-icon t
      doom-modeline-persp-name t
      doom-modeline-buffer-encoding nil
      doom-modeline-persp-name nil)
;; Hide direnv environment variables popup
(setq direnv-always-show-summary nil)
;; Change splash-screen banner
(setq fancy-splash-image "~/.doom.d/assets/emacs.svg")
;; Disable LSP documentation popup
(after! lsp-ui
  (setq lsp-ui-doc-enable nil
        lsp-signature-auto-activate nil
        lsp-enable-symbol-highlighting nil
        lsp-ui-sideline-show-code-actions nil
        lsp-modeline-code-actions-enable nil))
;; Shrink minibuffer
(after! vertico
  (setq vertico-count 8))
;; Eliminate gaps between windows
(after! frame
  (remove-hook 'doom-init-ui-hook #'window-divider-mode))
;; Disable lsp header line
(after! lsp-mode
  (setq lsp-headerline-breadcrumb-enable nil))
;; Shrink terminal buffer
(set-popup-rule! "^\\*vterm" :size 0.1 :vslot -4 :select t :quit nil :ttl 0)
;; Show matching parenthesis on the minibuffer
(after! smartparens (show-smartparens-global-mode t))
;; Modify the splash screen actions
(assoc-delete-all "Jump to bookmark" +doom-dashboard-menu-sections)
(assoc-delete-all "Open private configuration" +doom-dashboard-menu-sections)
(assoc-delete-all "Open documentation" +doom-dashboard-menu-sections)
(add-to-list '+doom-dashboard-menu-sections
             '("Open email client"
               :icon (all-the-icons-octicon "mail" :face 'doom-dashboard-menu-title)
               :when (featurep! :email mu4e)
               :face (:inherit (doom-dashboard-menu-title bold))
               :action =mu4e) t)
(add-to-list '+doom-dashboard-menu-sections
             '("RSS reader"
               :icon (all-the-icons-octicon "rss" :face 'doom-dashboard-menu-title)
               :when (featurep! :app rss)
               :face (:inherit (doom-dashboard-menu-title bold))
               :action =rss) t)
(add-to-list '+doom-dashboard-menu-sections
             '("Read saved articles"
               :icon (all-the-icons-octicon "book" :face 'doom-dashboard-menu-title)
               :face (:inherit (doom-dashboard-menu-title bold))
               :action =wallabag) t)
